@@ -11,18 +11,16 @@
 
 #include <algorithm>
 #include <cstddef>
+#include <stdlib.h>
 
 #include "../config/xsimd_align.hpp"
 
-#if defined(_MSC_VER) || defined(__MINGW64__) || defined(__MINGW32__)
-#include <malloc.h>
-#elif defined(__GNUC__)
-#include <mm_malloc.h>
 #if defined(XSIMD_ALLOCA)
+#if defined(__GNUC__)
 #include <alloca.h>
+#elif defined(_MSC_VER)
+#include <malloc.h>
 #endif
-#else
-#include <stdlib.h>
 #endif
 
 namespace xsimd
@@ -291,32 +289,12 @@ namespace xsimd
 
     inline void* aligned_malloc(size_t size, size_t alignment)
     {
-#if XSIMD_HAS_MM_MALLOC
-        return _mm_malloc(size, alignment);
-#elif XSIMD_HAS_POSIX_MEMALIGN
-        void* res;
-        const int failed = posix_memalign(&res, size, alignment);
-        if (failed)
-            res = 0;
-        return res;
-#elif (defined _MSC_VER)
-        return _aligned_malloc(size, alignment);
-#else
         return detail::xaligned_malloc(size, alignment);
-#endif
     }
 
     inline void aligned_free(void* ptr)
     {
-#if XSIMD_HAS_MM_MALLOC
-        _mm_free(ptr);
-#elif XSIMD_HAS_POSIX_MEMALIGN
-        free(ptr);
-#elif defined(_MSC_VER)
-        _aligned_free(ptr);
-#else
         detail::xaligned_free(ptr);
-#endif
     }
 
     template <class T>
