@@ -21,7 +21,6 @@ namespace xsimd
     template <>
     class batch_bool<double, 4> : public simd_batch_bool<batch_bool<double, 4>>
     {
-
     public:
 
         batch_bool();
@@ -65,7 +64,6 @@ namespace xsimd
     template <>
     class batch<double, 4> : public simd_batch<batch<double, 4>>
     {
-
     public:
 
         batch();
@@ -82,9 +80,27 @@ namespace xsimd
         batch& load_aligned(const double* src);
         batch& load_unaligned(const double* src);
 
+        batch& load_aligned(const float* src);
+        batch& load_unaligned(const float* src);
+
+        batch& load_aligned(const int32_t* src);
+        batch& load_unaligned(const int32_t* src);
+
+        batch& load_aligned(const int64_t* src);
+        batch& load_unaligned(const int64_t* src);
+
         void store_aligned(double* dst) const;
         void store_unaligned(double* dst) const;
 
+        void store_aligned(float* dst) const;
+        void store_unaligned(float* dst) const;
+
+        void store_aligned(int32_t* dst) const;
+        void store_unaligned(int32_t* dst) const;
+
+        void store_aligned(int64_t* dst) const;
+        void store_unaligned(int64_t* dst) const;
+
         double operator[](std::size_t index) const;
 
     private:
@@ -97,7 +113,7 @@ namespace xsimd
     batch<double, 4> operator-(const batch<double, 4>& lhs, const batch<double, 4>& rhs);
     batch<double, 4> operator*(const batch<double, 4>& lhs, const batch<double, 4>& rhs);
     batch<double, 4> operator/(const batch<double, 4>& lhs, const batch<double, 4>& rhs);
-    
+
     batch_bool<double, 4> operator==(const batch<double, 4>& lhs, const batch<double, 4>& rhs);
     batch_bool<double, 4> operator!=(const batch<double, 4>& lhs, const batch<double, 4>& rhs);
     batch_bool<double, 4> operator<(const batch<double, 4>& lhs, const batch<double, 4>& rhs);
@@ -128,7 +144,7 @@ namespace xsimd
 
     batch<double, 4> select(const batch_bool<double, 4>& cond, const batch<double, 4>& a, const batch<double, 4>& b);
 
-    batch_bool<double, 4> is_nan(const batch<double, 4>& x);
+    batch_bool<double, 4> isnan(const batch<double, 4>& x);
 
     /****************************************
      * batch_bool<double, 4> implementation *
@@ -145,8 +161,8 @@ namespace xsimd
 
     inline batch_bool<double, 4>::batch_bool(bool b0, bool b1, bool b2, bool b3)
         : m_value(_mm256_castsi256_pd(
-                  _mm256_setr_epi32(-(int)b0, -(int)b0, -(int)b1, -(int)b1,
-                                    -(int)b2, -(int)b2, -(int)b3, -(int)b3)))
+              _mm256_setr_epi32(-(int)b0, -(int)b0, -(int)b1, -(int)b1,
+                                -(int)b2, -(int)b2, -(int)b3, -(int)b3)))
     {
     }
 
@@ -228,7 +244,7 @@ namespace xsimd
         : m_value(_mm256_setr_pd(d0, d1, d2, d3))
     {
     }
-    
+
     inline batch<double, 4>::batch(const double* src)
         : m_value(_mm256_loadu_pd(src))
     {
@@ -272,6 +288,46 @@ namespace xsimd
         return *this;
     }
 
+    inline batch<double, 4>& batch<double, 4>::load_aligned(const float* src)
+    {
+        m_value = _mm256_cvtps_pd(_mm_load_ps(src));
+        return *this;
+    }
+
+    inline batch<double, 4>& batch<double, 4>::load_unaligned(const float* src)
+    {
+        m_value = _mm256_cvtps_pd(_mm_loadu_ps(src));
+        return *this;
+    }
+
+    inline batch<double, 4>& batch<double, 4>::load_aligned(const int32_t* src)
+    {
+        m_value = _mm256_cvtepi32_pd(_mm_load_si128((__m128i const*)src));
+        return *this;
+    }
+
+    inline batch<double, 4>& batch<double, 4>::load_unaligned(const int32_t* src)
+    {
+        m_value = _mm256_cvtepi32_pd(_mm_loadu_si128((__m128i const*)src));
+        return *this;
+    }
+
+    inline batch<double, 4>& batch<double, 4>::load_aligned(const int64_t* src)
+    {
+        alignas(32) double tmp[4];
+        tmp[0] = double(src[0]);
+        tmp[1] = double(src[1]);
+        tmp[2] = double(src[2]);
+        tmp[3] = double(src[3]);
+        m_value = _mm256_load_pd(tmp);
+        return *this;
+    }
+
+    inline batch<double, 4>& batch<double, 4>::load_unaligned(const int64_t* src)
+    {
+        return load_aligned(src);
+    }
+
     inline void batch<double, 4>::store_aligned(double* dst) const
     {
         _mm256_store_pd(dst, m_value);
@@ -282,6 +338,41 @@ namespace xsimd
         _mm256_storeu_pd(dst, m_value);
     }
 
+    inline void batch<double, 4>::store_aligned(float* dst) const
+    {
+        _mm_store_ps(dst, _mm256_cvtpd_ps(m_value));
+    }
+
+    inline void batch<double, 4>::store_unaligned(float* dst) const
+    {
+        _mm_store_ps(dst, _mm256_cvtpd_ps(m_value));
+    }
+
+    inline void batch<double, 4>::store_aligned(int32_t* dst) const
+    {
+        _mm_store_si128((__m128i*)dst, _mm256_cvtpd_epi32(m_value));
+    }
+
+    inline void batch<double, 4>::store_unaligned(int32_t* dst) const
+    {
+        _mm_storeu_si128((__m128i*)dst, _mm256_cvtpd_epi32(m_value));
+    }
+
+    inline void batch<double, 4>::store_aligned(int64_t* dst) const
+    {
+        alignas(32) double tmp[4];
+        _mm256_store_pd(tmp, m_value);
+        dst[0] = static_cast<int64_t>(tmp[0]);
+        dst[1] = static_cast<int64_t>(tmp[1]);
+        dst[2] = static_cast<int64_t>(tmp[2]);
+        dst[3] = static_cast<int64_t>(tmp[3]);
+    }
+
+    inline void batch<double, 4>::store_unaligned(int64_t* dst) const
+    {
+        store_aligned(dst);
+    }
+
     inline double batch<double, 4>::operator[](std::size_t index) const
     {
         alignas(32) double x[4];
@@ -313,7 +404,7 @@ namespace xsimd
     {
         return _mm256_div_pd(lhs, rhs);
     }
-    
+
     inline batch_bool<double, 4> operator==(const batch<double, 4>& lhs, const batch<double, 4>& rhs)
     {
         return _mm256_cmp_pd(lhs, rhs, _CMP_EQ_OQ);
@@ -381,7 +472,7 @@ namespace xsimd
 
     inline batch<double, 4> abs(const batch<double, 4>& rhs)
     {
-        __m256d sign_mask = _mm256_set1_pd(-0.); // -0. = 1 << 63
+        __m256d sign_mask = _mm256_set1_pd(-0.);  // -0. = 1 << 63
         return _mm256_andnot_pd(sign_mask, rhs);
     }
 
@@ -470,7 +561,7 @@ namespace xsimd
         return _mm256_blendv_pd(b, a, cond);
     }
 
-    inline batch_bool<double, 4> is_nan(const batch<double, 4>& x)
+    inline batch_bool<double, 4> isnan(const batch<double, 4>& x)
     {
         return _mm256_cmp_pd(x, x, _CMP_UNORD_Q);
     }
