@@ -21,13 +21,12 @@ namespace xsimd
     template <>
     class batch_bool<float, 8> : public simd_batch_bool<batch_bool<float, 8>>
     {
-
     public:
 
         batch_bool();
         explicit batch_bool(bool b);
         batch_bool(bool b0, bool b1, bool b2, bool b3,
-                  bool b4, bool b5, bool b6, bool b7);
+                   bool b4, bool b5, bool b6, bool b7);
         batch_bool(const __m256& rhs);
         batch_bool& operator=(const __m256& rhs);
 
@@ -65,7 +64,6 @@ namespace xsimd
     template <>
     class batch<float, 8> : public simd_batch<batch<float, 8>>
     {
-
     public:
 
         batch();
@@ -83,9 +81,27 @@ namespace xsimd
         batch& load_aligned(const float* src);
         batch& load_unaligned(const float* src);
 
+        batch& load_aligned(const double* src);
+        batch& load_unaligned(const double* src);
+
+        batch& load_aligned(const int32_t* src);
+        batch& load_unaligned(const int32_t* src);
+
+        batch& load_aligned(const int64_t* src);
+        batch& load_unaligned(const int64_t* src);
+
         void store_aligned(float* dst) const;
         void store_unaligned(float* dst) const;
 
+        void store_aligned(double* dst) const;
+        void store_unaligned(double* dst) const;
+
+        void store_aligned(int32_t* dst) const;
+        void store_unaligned(int32_t* dst) const;
+
+        void store_aligned(int64_t* dst) const;
+        void store_unaligned(int64_t* dst) const;
+
         float operator[](std::size_t index) const;
 
     private:
@@ -98,7 +114,7 @@ namespace xsimd
     batch<float, 8> operator-(const batch<float, 8>& lhs, const batch<float, 8>& rhs);
     batch<float, 8> operator*(const batch<float, 8>& lhs, const batch<float, 8>& rhs);
     batch<float, 8> operator/(const batch<float, 8>& lhs, const batch<float, 8>& rhs);
-    
+
     batch_bool<float, 8> operator==(const batch<float, 8>& lhs, const batch<float, 8>& rhs);
     batch_bool<float, 8> operator!=(const batch<float, 8>& lhs, const batch<float, 8>& rhs);
     batch_bool<float, 8> operator<(const batch<float, 8>& lhs, const batch<float, 8>& rhs);
@@ -123,13 +139,13 @@ namespace xsimd
     batch<float, 8> fms(const batch<float, 8>& x, const batch<float, 8>& y, const batch<float, 8>& z);
     batch<float, 8> fnma(const batch<float, 8>& x, const batch<float, 8>& y, const batch<float, 8>& z);
     batch<float, 8> fnms(const batch<float, 8>& x, const batch<float, 8>& y, const batch<float, 8>& z);
-    
+
     float hadd(const batch<float, 8>& rhs);
     batch<float, 8> haddp(const batch<float, 8>* row);
 
     batch<float, 8> select(const batch_bool<float, 8>& cond, const batch<float, 8>& a, const batch<float, 8>& b);
 
-    batch_bool<float, 8> is_nan(const batch<float, 8>& x);
+    batch_bool<float, 8> isnan(const batch<float, 8>& x);
 
     /***************************************
      * batch_bool<float, 8> implementation *
@@ -146,9 +162,9 @@ namespace xsimd
 
     inline batch_bool<float, 8>::batch_bool(bool b0, bool b1, bool b2, bool b3,
                                             bool b4, bool b5, bool b6, bool b7)
-            : m_value(_mm256_castsi256_ps(
-                  _mm256_setr_epi32(-(int)b0, -(int)b1, -(int)b2, -(int)b3,
-                                    -(int)b4, -(int)b5, -(int)b6, -(int)b7)))
+        : m_value(_mm256_castsi256_ps(
+              _mm256_setr_epi32(-(int)b0, -(int)b1, -(int)b2, -(int)b3,
+                                -(int)b4, -(int)b5, -(int)b6, -(int)b7)))
     {
     }
 
@@ -245,8 +261,8 @@ namespace xsimd
     inline batch<float, 8>::batch(const float* src, unaligned_mode)
         : m_value(_mm256_loadu_ps(src))
     {
-
     }
+
     inline batch<float, 8>::batch(const __m256& rhs)
         : m_value(rhs)
     {
@@ -275,6 +291,56 @@ namespace xsimd
         return *this;
     }
 
+    inline batch<float, 8>& batch<float, 8>::load_aligned(const double* src)
+    {
+        __m128 tmp1 = _mm256_cvtpd_ps(_mm256_load_pd(src));
+        __m128 tmp2 = _mm256_cvtpd_ps(_mm256_load_pd(src + 4));
+        m_value = _mm256_castps128_ps256(tmp1);
+        m_value = _mm256_insertf128_ps(m_value, tmp2, 1);
+        return *this;
+    }
+
+    inline batch<float, 8>& batch<float, 8>::load_unaligned(const double* src)
+    {
+        __m128 tmp1 = _mm256_cvtpd_ps(_mm256_loadu_pd(src));
+        __m128 tmp2 = _mm256_cvtpd_ps(_mm256_loadu_pd(src + 4));
+        m_value = _mm256_castps128_ps256(tmp1);
+        m_value = _mm256_insertf128_ps(m_value, tmp2, 1);
+        return *this;
+    }
+
+    inline batch<float, 8>& batch<float, 8>::load_aligned(const int32_t* src)
+    {
+        m_value = _mm256_cvtepi32_ps(_mm256_load_si256((__m256i const*)src));
+        return *this;
+    }
+
+    inline batch<float, 8>& batch<float, 8>::load_unaligned(const int32_t* src)
+    {
+        m_value = _mm256_cvtepi32_ps(_mm256_loadu_si256((__m256i const*)src));
+        return *this;
+    }
+
+    inline batch<float, 8>& batch<float, 8>::load_aligned(const int64_t* src)
+    {
+        alignas(32) float tmp[8];
+        tmp[0] = float(src[0]);
+        tmp[1] = float(src[1]);
+        tmp[2] = float(src[2]);
+        tmp[3] = float(src[3]);
+        tmp[4] = float(src[4]);
+        tmp[5] = float(src[5]);
+        tmp[6] = float(src[6]);
+        tmp[7] = float(src[7]);
+        m_value = _mm256_load_ps(tmp);
+        return *this;
+    }
+
+    inline batch<float, 8>& batch<float, 8>::load_unaligned(const int64_t* src)
+    {
+        return load_aligned(src);
+    }
+
     inline void batch<float, 8>::store_aligned(float* dst) const
     {
         _mm256_store_ps(dst, m_value);
@@ -285,6 +351,54 @@ namespace xsimd
         _mm256_store_ps(dst, m_value);
     }
 
+    inline void batch<float, 8>::store_aligned(double* dst) const
+    {
+        alignas(32) float tmp[8];
+        _mm256_store_ps(tmp, m_value);
+        dst[0] = static_cast<double>(tmp[0]);
+        dst[1] = static_cast<double>(tmp[1]);
+        dst[2] = static_cast<double>(tmp[2]);
+        dst[3] = static_cast<double>(tmp[3]);
+        dst[4] = static_cast<double>(tmp[4]);
+        dst[5] = static_cast<double>(tmp[5]);
+        dst[6] = static_cast<double>(tmp[6]);
+        dst[7] = static_cast<double>(tmp[7]);
+    }
+
+    inline void batch<float, 8>::store_unaligned(double* dst) const
+    {
+        store_aligned(dst);
+    }
+
+    inline void batch<float, 8>::store_aligned(int32_t* dst) const
+    {
+        _mm256_store_si256((__m256i*)dst, _mm256_cvtps_epi32(m_value));
+    }
+
+    inline void batch<float, 8>::store_unaligned(int32_t* dst) const
+    {
+        _mm256_storeu_si256((__m256i*)dst, _mm256_cvtps_epi32(m_value));
+    }
+
+    inline void batch<float, 8>::store_aligned(int64_t* dst) const
+    {
+        alignas(32) float tmp[8];
+        _mm256_store_ps(tmp, m_value);
+        dst[0] = static_cast<int64_t>(tmp[0]);
+        dst[1] = static_cast<int64_t>(tmp[1]);
+        dst[2] = static_cast<int64_t>(tmp[2]);
+        dst[3] = static_cast<int64_t>(tmp[3]);
+        dst[4] = static_cast<int64_t>(tmp[4]);
+        dst[5] = static_cast<int64_t>(tmp[5]);
+        dst[6] = static_cast<int64_t>(tmp[6]);
+        dst[7] = static_cast<int64_t>(tmp[7]);
+    }
+
+    inline void batch<float, 8>::store_unaligned(int64_t* dst) const
+    {
+        store_aligned(dst);
+    }
+
     inline float batch<float, 8>::operator[](std::size_t index) const
     {
         alignas(32) float x[8];
@@ -316,7 +430,7 @@ namespace xsimd
     {
         return _mm256_div_ps(lhs, rhs);
     }
-    
+
     inline batch_bool<float, 8> operator==(const batch<float, 8>& lhs, const batch<float, 8>& rhs)
     {
         return _mm256_cmp_ps(lhs, rhs, _CMP_EQ_OQ);
@@ -346,12 +460,12 @@ namespace xsimd
     {
         return _mm256_or_ps(lhs, rhs);
     }
-    
+
     inline batch<float, 8> operator^(const batch<float, 8>& lhs, const batch<float, 8>& rhs)
     {
         return _mm256_xor_ps(lhs, rhs);
     }
-    
+
     inline batch<float, 8> operator~(const batch<float, 8>& rhs)
     {
         return _mm256_xor_ps(rhs, _mm256_castsi256_ps(_mm256_set1_epi32(-1)));
@@ -384,7 +498,7 @@ namespace xsimd
 
     inline batch<float, 8> abs(const batch<float, 8>& rhs)
     {
-        __m256 sign_mask = _mm256_set1_ps(-0.f); // -0.f = 1 << 31
+        __m256 sign_mask = _mm256_set1_ps(-0.f);  // -0.f = 1 << 31
         return _mm256_andnot_ps(sign_mask, rhs);
     }
 
@@ -491,12 +605,10 @@ namespace xsimd
         return _mm256_blendv_ps(b, a, cond);
     }
 
-    
-    inline batch_bool<float, 8> is_nan(const batch<float, 8>& x)
+    inline batch_bool<float, 8> isnan(const batch<float, 8>& x)
     {
         return _mm256_cmp_ps(x, x, _CMP_UNORD_Q);
     }
 }
 
 #endif
-
