@@ -10,6 +10,7 @@
 #define XSIMD_AVX_INT32_HPP
 
 #include <cstdint>
+
 #include "xsimd_base.hpp"
 
 namespace xsimd
@@ -22,7 +23,6 @@ namespace xsimd
     template <>
     class batch_bool<int32_t, 8> : public simd_batch_bool<batch_bool<int32_t, 8>>
     {
-
     public:
 
         batch_bool();
@@ -65,7 +65,6 @@ namespace xsimd
     template <>
     class batch<int32_t, 8> : public simd_batch<batch<int32_t, 8>>
     {
-
     public:
 
         batch();
@@ -82,9 +81,27 @@ namespace xsimd
         batch& load_aligned(const int32_t* src);
         batch& load_unaligned(const int32_t* src);
 
+        batch& load_aligned(const int64_t* src);
+        batch& load_unaligned(const int64_t* src);
+
+        batch& load_aligned(const float* src);
+        batch& load_unaligned(const float* src);
+
+        batch& load_aligned(const double* src);
+        batch& load_unaligned(const double* src);
+
         void store_aligned(int32_t* dst) const;
         void store_unaligned(int32_t* dst) const;
 
+        void store_aligned(int64_t* dst) const;
+        void store_unaligned(int64_t* dst) const;
+
+        void store_aligned(float* dst) const;
+        void store_unaligned(float* dst) const;
+
+        void store_aligned(double* dst) const;
+        void store_unaligned(double* dst) const;
+
         int32_t operator[](std::size_t index) const;
 
     private:
@@ -132,19 +149,19 @@ namespace xsimd
 
 #if XSIMD_X86_INSTR_SET < XSIMD_X86_AVX2_VERSION
 
-#define XSIMD_SPLIT_AVX(avx_name)\
-    __m128i avx_name##_low = _mm256_castsi256_si128(avx_name);\
+#define XSIMD_SPLIT_AVX(avx_name)                              \
+    __m128i avx_name##_low = _mm256_castsi256_si128(avx_name); \
     __m128i avx_name##_high = _mm256_extractf128_si256(avx_name, 1)
 
-#define XSIMD_RETURN_MERGED_SSE(res_low, res_high)\
-    __m256i result = _mm256_castsi128_si256(res_low);\
+#define XSIMD_RETURN_MERGED_SSE(res_low, res_high)    \
+    __m256i result = _mm256_castsi128_si256(res_low); \
     return _mm256_insertf128_si256(result, res_high, 1)
 
-#define XSIMD_APPLY_SSE_FUNCTION(func, avx_lhs, avx_rhs)\
-    XSIMD_SPLIT_AVX(avx_lhs);\
-    XSIMD_SPLIT_AVX(avx_rhs);\
-    __m128i res_low = func(avx_lhs##_low, avx_rhs##_low);\
-    __m128i res_high = func(avx_lhs##_high, avx_rhs##_high);\
+#define XSIMD_APPLY_SSE_FUNCTION(func, avx_lhs, avx_rhs)     \
+    XSIMD_SPLIT_AVX(avx_lhs);                                \
+    XSIMD_SPLIT_AVX(avx_rhs);                                \
+    __m128i res_low = func(avx_lhs##_low, avx_rhs##_low);    \
+    __m128i res_high = func(avx_lhs##_high, avx_rhs##_high); \
     XSIMD_RETURN_MERGED_SSE(res_low, res_high);
 #endif
 
@@ -311,6 +328,56 @@ namespace xsimd
         return *this;
     }
 
+    inline batch<int32_t, 8>& batch<int32_t, 8>::load_aligned(const int64_t* src)
+    {
+        alignas(32) int32_t tmp[8];
+        tmp[0] = static_cast<int32_t>(src[0]);
+        tmp[1] = static_cast<int32_t>(src[1]);
+        tmp[2] = static_cast<int32_t>(src[2]);
+        tmp[3] = static_cast<int32_t>(src[3]);
+        tmp[4] = static_cast<int32_t>(src[4]);
+        tmp[5] = static_cast<int32_t>(src[5]);
+        tmp[6] = static_cast<int32_t>(src[6]);
+        tmp[7] = static_cast<int32_t>(src[7]);
+        m_value = _mm256_load_si256((__m256i const*)tmp);
+        return *this;
+    }
+
+    inline batch<int32_t, 8>& batch<int32_t, 8>::load_unaligned(const int64_t* src)
+    {
+        return load_aligned(src);
+    }
+
+    inline batch<int32_t, 8>& batch<int32_t, 8>::load_aligned(const float* src)
+    {
+        m_value = _mm256_cvtps_epi32(_mm256_load_ps(src));
+        return *this;
+    }
+
+    inline batch<int32_t, 8>& batch<int32_t, 8>::load_unaligned(const float* src)
+    {
+        m_value = _mm256_cvtps_epi32(_mm256_loadu_ps(src));
+        return *this;
+    }
+
+    inline batch<int32_t, 8>& batch<int32_t, 8>::load_aligned(const double* src)
+    {
+        __m128i tmp1 = _mm256_cvtpd_epi32(_mm256_load_pd(src));
+        __m128i tmp2 = _mm256_cvtpd_epi32(_mm256_load_pd(src + 4));
+        m_value = _mm256_castsi128_si256(tmp1);
+        m_value = _mm256_insertf128_si256(m_value, tmp2, 1);
+        return *this;
+    }
+
+    inline batch<int32_t, 8>& batch<int32_t, 8>::load_unaligned(const double* src)
+    {
+        __m128i tmp1 = _mm256_cvtpd_epi32(_mm256_loadu_pd(src));
+        __m128i tmp2 = _mm256_cvtpd_epi32(_mm256_loadu_pd(src + 4));
+        m_value = _mm256_castsi128_si256(tmp1);
+        m_value = _mm256_insertf128_si256(m_value, tmp2, 1);
+        return *this;
+    }
+
     inline void batch<int32_t, 8>::store_aligned(int32_t* dst) const
     {
         _mm256_store_si256((__m256i*)dst, m_value);
@@ -321,6 +388,51 @@ namespace xsimd
         _mm256_storeu_si256((__m256i*)dst, m_value);
     }
 
+    inline void batch<int32_t, 8>::store_aligned(int64_t* dst) const
+    {
+        alignas(32) int32_t tmp[8];
+        store_aligned(tmp);
+        dst[0] = int64_t(tmp[0]);
+        dst[1] = int64_t(tmp[1]);
+        dst[2] = int64_t(tmp[2]);
+        dst[3] = int64_t(tmp[3]);
+        dst[4] = int64_t(tmp[4]);
+        dst[5] = int64_t(tmp[5]);
+        dst[6] = int64_t(tmp[6]);
+        dst[7] = int64_t(tmp[7]);
+    }
+
+    inline void batch<int32_t, 8>::store_unaligned(int64_t* dst) const
+    {
+        store_aligned(dst);
+    }
+
+    inline void batch<int32_t, 8>::store_aligned(float* dst) const
+    {
+        _mm256_store_ps(dst, _mm256_cvtepi32_ps(m_value));
+    }
+
+    inline void batch<int32_t, 8>::store_unaligned(float* dst) const
+    {
+        _mm256_storeu_ps(dst, _mm256_cvtepi32_ps(m_value));
+    }
+
+    inline void batch<int32_t, 8>::store_aligned(double* dst) const
+    {
+        __m128i tmp1 = _mm256_extractf128_si256(m_value, 0);
+        __m128i tmp2 = _mm256_extractf128_si256(m_value, 1);
+        _mm256_store_pd(dst, _mm256_cvtepi32_pd(tmp1));
+        _mm256_store_pd(dst + 4 , _mm256_cvtepi32_pd(tmp2));
+    }
+
+    inline void batch<int32_t, 8>::store_unaligned(double* dst) const
+    {
+        __m128i tmp1 = _mm256_extractf128_si256(m_value, 0);
+        __m128i tmp2 = _mm256_extractf128_si256(m_value, 1);
+        _mm256_storeu_pd(dst, _mm256_cvtepi32_pd(tmp1));
+        _mm256_storeu_pd(dst + 4, _mm256_cvtepi32_pd(tmp2));
+    }
+
     inline int32_t batch<int32_t, 8>::operator[](std::size_t index) const
     {
         alignas(32) int32_t x[8];
@@ -487,7 +599,7 @@ namespace xsimd
     {
         return x * y - z;
     }
-    
+
     inline batch<int32_t, 8> fnma(const batch<int32_t, 8>& x, const batch<int32_t, 8>& y, const batch<int32_t, 8>& z)
     {
         return -x * y + z;
@@ -552,7 +664,6 @@ namespace xsimd
         XSIMD_RETURN_MERGED_SSE(res_low, res_high);
 #endif
     }
-
 }
 
 #undef XSIMD_APPLY_SSE_FUNCTION
@@ -560,4 +671,3 @@ namespace xsimd
 #undef XSIMD_SPLIT_AVX
 
 #endif
-
